# coding: utf-8

"""
    Cyberwave API

    Cyberwave platform REST API. Use 'Bearer YOUR_TOKEN' for authentication.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class Visibility(str, Enum):
    """
    Visibility levels for objects.
    """

    """
    allowed enum values
    """
    PRIVATE = 'private'
    LINK = 'link'
    PROJECT = 'project'
    WORKSPACE = 'workspace'
    ORG = 'org'
    PUBLIC = 'public'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of Visibility from a JSON string"""
        return cls(json.loads(json_str))


