# coding: utf-8

"""
    Cyberwave API

    Cyberwave platform REST API. Use 'Bearer YOUR_TOKEN' for authentication.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class TwinCreateSchema(BaseModel):
    """
    Schema for creating and updating a twin.
    """ # noqa: E501
    name: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    asset_uuid: Optional[StrictStr] = None
    environment_uuid: Optional[StrictStr] = None
    position_x: Optional[Union[StrictFloat, StrictInt]] = None
    position_y: Optional[Union[StrictFloat, StrictInt]] = None
    position_z: Optional[Union[StrictFloat, StrictInt]] = None
    rotation_w: Optional[Union[StrictFloat, StrictInt]] = None
    rotation_x: Optional[Union[StrictFloat, StrictInt]] = None
    rotation_y: Optional[Union[StrictFloat, StrictInt]] = None
    rotation_z: Optional[Union[StrictFloat, StrictInt]] = None
    scale_x: Optional[Union[StrictFloat, StrictInt]] = None
    scale_y: Optional[Union[StrictFloat, StrictInt]] = None
    scale_z: Optional[Union[StrictFloat, StrictInt]] = None
    kinematics_override: Optional[Dict[str, Any]] = None
    joint_calibration: Optional[Dict[str, Any]] = None
    metadata: Optional[Dict[str, Any]] = None
    controller_policy_uuid: Optional[StrictStr] = None
    attach_to_twin_uuid: Optional[StrictStr] = None
    attach_to_link: Optional[StrictStr] = None
    attach_offset_x: Optional[Union[StrictFloat, StrictInt]] = None
    attach_offset_y: Optional[Union[StrictFloat, StrictInt]] = None
    attach_offset_z: Optional[Union[StrictFloat, StrictInt]] = None
    attach_offset_rotation_w: Optional[Union[StrictFloat, StrictInt]] = None
    attach_offset_rotation_x: Optional[Union[StrictFloat, StrictInt]] = None
    attach_offset_rotation_y: Optional[Union[StrictFloat, StrictInt]] = None
    attach_offset_rotation_z: Optional[Union[StrictFloat, StrictInt]] = None
    fixed_base: Optional[StrictBool] = None
    __properties: ClassVar[List[str]] = ["name", "description", "asset_uuid", "environment_uuid", "position_x", "position_y", "position_z", "rotation_w", "rotation_x", "rotation_y", "rotation_z", "scale_x", "scale_y", "scale_z", "kinematics_override", "joint_calibration", "metadata", "controller_policy_uuid", "attach_to_twin_uuid", "attach_to_link", "attach_offset_x", "attach_offset_y", "attach_offset_z", "attach_offset_rotation_w", "attach_offset_rotation_x", "attach_offset_rotation_y", "attach_offset_rotation_z", "fixed_base"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TwinCreateSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if name (nullable) is None
        # and model_fields_set contains the field
        if self.name is None and "name" in self.model_fields_set:
            _dict['name'] = None

        # set to None if description (nullable) is None
        # and model_fields_set contains the field
        if self.description is None and "description" in self.model_fields_set:
            _dict['description'] = None

        # set to None if asset_uuid (nullable) is None
        # and model_fields_set contains the field
        if self.asset_uuid is None and "asset_uuid" in self.model_fields_set:
            _dict['asset_uuid'] = None

        # set to None if environment_uuid (nullable) is None
        # and model_fields_set contains the field
        if self.environment_uuid is None and "environment_uuid" in self.model_fields_set:
            _dict['environment_uuid'] = None

        # set to None if position_x (nullable) is None
        # and model_fields_set contains the field
        if self.position_x is None and "position_x" in self.model_fields_set:
            _dict['position_x'] = None

        # set to None if position_y (nullable) is None
        # and model_fields_set contains the field
        if self.position_y is None and "position_y" in self.model_fields_set:
            _dict['position_y'] = None

        # set to None if position_z (nullable) is None
        # and model_fields_set contains the field
        if self.position_z is None and "position_z" in self.model_fields_set:
            _dict['position_z'] = None

        # set to None if rotation_w (nullable) is None
        # and model_fields_set contains the field
        if self.rotation_w is None and "rotation_w" in self.model_fields_set:
            _dict['rotation_w'] = None

        # set to None if rotation_x (nullable) is None
        # and model_fields_set contains the field
        if self.rotation_x is None and "rotation_x" in self.model_fields_set:
            _dict['rotation_x'] = None

        # set to None if rotation_y (nullable) is None
        # and model_fields_set contains the field
        if self.rotation_y is None and "rotation_y" in self.model_fields_set:
            _dict['rotation_y'] = None

        # set to None if rotation_z (nullable) is None
        # and model_fields_set contains the field
        if self.rotation_z is None and "rotation_z" in self.model_fields_set:
            _dict['rotation_z'] = None

        # set to None if scale_x (nullable) is None
        # and model_fields_set contains the field
        if self.scale_x is None and "scale_x" in self.model_fields_set:
            _dict['scale_x'] = None

        # set to None if scale_y (nullable) is None
        # and model_fields_set contains the field
        if self.scale_y is None and "scale_y" in self.model_fields_set:
            _dict['scale_y'] = None

        # set to None if scale_z (nullable) is None
        # and model_fields_set contains the field
        if self.scale_z is None and "scale_z" in self.model_fields_set:
            _dict['scale_z'] = None

        # set to None if kinematics_override (nullable) is None
        # and model_fields_set contains the field
        if self.kinematics_override is None and "kinematics_override" in self.model_fields_set:
            _dict['kinematics_override'] = None

        # set to None if joint_calibration (nullable) is None
        # and model_fields_set contains the field
        if self.joint_calibration is None and "joint_calibration" in self.model_fields_set:
            _dict['joint_calibration'] = None

        # set to None if metadata (nullable) is None
        # and model_fields_set contains the field
        if self.metadata is None and "metadata" in self.model_fields_set:
            _dict['metadata'] = None

        # set to None if controller_policy_uuid (nullable) is None
        # and model_fields_set contains the field
        if self.controller_policy_uuid is None and "controller_policy_uuid" in self.model_fields_set:
            _dict['controller_policy_uuid'] = None

        # set to None if attach_to_twin_uuid (nullable) is None
        # and model_fields_set contains the field
        if self.attach_to_twin_uuid is None and "attach_to_twin_uuid" in self.model_fields_set:
            _dict['attach_to_twin_uuid'] = None

        # set to None if attach_to_link (nullable) is None
        # and model_fields_set contains the field
        if self.attach_to_link is None and "attach_to_link" in self.model_fields_set:
            _dict['attach_to_link'] = None

        # set to None if attach_offset_x (nullable) is None
        # and model_fields_set contains the field
        if self.attach_offset_x is None and "attach_offset_x" in self.model_fields_set:
            _dict['attach_offset_x'] = None

        # set to None if attach_offset_y (nullable) is None
        # and model_fields_set contains the field
        if self.attach_offset_y is None and "attach_offset_y" in self.model_fields_set:
            _dict['attach_offset_y'] = None

        # set to None if attach_offset_z (nullable) is None
        # and model_fields_set contains the field
        if self.attach_offset_z is None and "attach_offset_z" in self.model_fields_set:
            _dict['attach_offset_z'] = None

        # set to None if attach_offset_rotation_w (nullable) is None
        # and model_fields_set contains the field
        if self.attach_offset_rotation_w is None and "attach_offset_rotation_w" in self.model_fields_set:
            _dict['attach_offset_rotation_w'] = None

        # set to None if attach_offset_rotation_x (nullable) is None
        # and model_fields_set contains the field
        if self.attach_offset_rotation_x is None and "attach_offset_rotation_x" in self.model_fields_set:
            _dict['attach_offset_rotation_x'] = None

        # set to None if attach_offset_rotation_y (nullable) is None
        # and model_fields_set contains the field
        if self.attach_offset_rotation_y is None and "attach_offset_rotation_y" in self.model_fields_set:
            _dict['attach_offset_rotation_y'] = None

        # set to None if attach_offset_rotation_z (nullable) is None
        # and model_fields_set contains the field
        if self.attach_offset_rotation_z is None and "attach_offset_rotation_z" in self.model_fields_set:
            _dict['attach_offset_rotation_z'] = None

        # set to None if fixed_base (nullable) is None
        # and model_fields_set contains the field
        if self.fixed_base is None and "fixed_base" in self.model_fields_set:
            _dict['fixed_base'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TwinCreateSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "name": obj.get("name"),
            "description": obj.get("description"),
            "asset_uuid": obj.get("asset_uuid"),
            "environment_uuid": obj.get("environment_uuid"),
            "position_x": obj.get("position_x"),
            "position_y": obj.get("position_y"),
            "position_z": obj.get("position_z"),
            "rotation_w": obj.get("rotation_w"),
            "rotation_x": obj.get("rotation_x"),
            "rotation_y": obj.get("rotation_y"),
            "rotation_z": obj.get("rotation_z"),
            "scale_x": obj.get("scale_x"),
            "scale_y": obj.get("scale_y"),
            "scale_z": obj.get("scale_z"),
            "kinematics_override": obj.get("kinematics_override"),
            "joint_calibration": obj.get("joint_calibration"),
            "metadata": obj.get("metadata"),
            "controller_policy_uuid": obj.get("controller_policy_uuid"),
            "attach_to_twin_uuid": obj.get("attach_to_twin_uuid"),
            "attach_to_link": obj.get("attach_to_link"),
            "attach_offset_x": obj.get("attach_offset_x"),
            "attach_offset_y": obj.get("attach_offset_y"),
            "attach_offset_z": obj.get("attach_offset_z"),
            "attach_offset_rotation_w": obj.get("attach_offset_rotation_w"),
            "attach_offset_rotation_x": obj.get("attach_offset_rotation_x"),
            "attach_offset_rotation_y": obj.get("attach_offset_rotation_y"),
            "attach_offset_rotation_z": obj.get("attach_offset_rotation_z"),
            "fixed_base": obj.get("fixed_base")
        })
        return _obj


