# coding: utf-8

"""
    Cyberwave API

    Cyberwave platform REST API. Use 'Bearer YOUR_TOKEN' for authentication.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cyberwave.rest.models.visibility import Visibility
from typing import Optional, Set
from typing_extensions import Self

class CloudNodeInstanceCreateRequest(BaseModel):
    """
    CloudNodeInstanceCreateRequest
    """ # noqa: E501
    profile_slug: StrictStr
    slug: Optional[StrictStr] = None
    workspace_uuid: Optional[StrictStr] = None
    provider: Optional[StrictStr] = 'self-hosted'
    visibility: Optional[Visibility] = None
    __properties: ClassVar[List[str]] = ["profile_slug", "slug", "workspace_uuid", "provider", "visibility"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CloudNodeInstanceCreateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if slug (nullable) is None
        # and model_fields_set contains the field
        if self.slug is None and "slug" in self.model_fields_set:
            _dict['slug'] = None

        # set to None if workspace_uuid (nullable) is None
        # and model_fields_set contains the field
        if self.workspace_uuid is None and "workspace_uuid" in self.model_fields_set:
            _dict['workspace_uuid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CloudNodeInstanceCreateRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "profile_slug": obj.get("profile_slug"),
            "slug": obj.get("slug"),
            "workspace_uuid": obj.get("workspace_uuid"),
            "provider": obj.get("provider") if obj.get("provider") is not None else 'self-hosted',
            "visibility": obj.get("visibility")
        })
        return _obj


