# coding: utf-8

"""
    Cyberwave API

    Cyberwave platform REST API. Use 'Bearer YOUR_TOKEN' for authentication.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from typing import Optional, Set
from typing_extensions import Self

class TwinSchema(BaseModel):
    """
    TwinSchema
    """ # noqa: E501
    uuid: StrictStr
    name: StrictStr
    description: StrictStr
    asset_uuid: StrictStr
    environment_uuid: StrictStr
    created_at: datetime
    updated_at: datetime
    glb_file: Optional[StrictStr]
    urdf_file: Optional[StrictStr]
    position_x: Union[StrictFloat, StrictInt]
    position_y: Union[StrictFloat, StrictInt]
    position_z: Union[StrictFloat, StrictInt]
    rotation_w: Union[StrictFloat, StrictInt]
    rotation_x: Union[StrictFloat, StrictInt]
    rotation_y: Union[StrictFloat, StrictInt]
    rotation_z: Union[StrictFloat, StrictInt]
    scale_x: Union[StrictFloat, StrictInt]
    scale_y: Union[StrictFloat, StrictInt]
    scale_z: Union[StrictFloat, StrictInt]
    joint_states: Optional[Dict[str, Any]] = None
    kinematics_override: Optional[Dict[str, Any]] = None
    joint_calibration: Optional[Dict[str, Any]] = None
    metadata: Dict[str, Any]
    capabilities: Dict[str, Any]
    controller_policy_uuid: Optional[StrictStr] = None
    visibility: Optional[StrictStr] = None
    attach_to_twin_uuid: Optional[StrictStr] = None
    attach_to_link: Optional[StrictStr] = None
    attach_offset_x: Union[StrictFloat, StrictInt]
    attach_offset_y: Union[StrictFloat, StrictInt]
    attach_offset_z: Union[StrictFloat, StrictInt]
    attach_offset_rotation_w: Union[StrictFloat, StrictInt]
    attach_offset_rotation_x: Union[StrictFloat, StrictInt]
    attach_offset_rotation_y: Union[StrictFloat, StrictInt]
    attach_offset_rotation_z: Union[StrictFloat, StrictInt]
    fixed_base: StrictBool
    __properties: ClassVar[List[str]] = ["uuid", "name", "description", "asset_uuid", "environment_uuid", "created_at", "updated_at", "glb_file", "urdf_file", "position_x", "position_y", "position_z", "rotation_w", "rotation_x", "rotation_y", "rotation_z", "scale_x", "scale_y", "scale_z", "joint_states", "kinematics_override", "joint_calibration", "metadata", "capabilities", "controller_policy_uuid", "visibility", "attach_to_twin_uuid", "attach_to_link", "attach_offset_x", "attach_offset_y", "attach_offset_z", "attach_offset_rotation_w", "attach_offset_rotation_x", "attach_offset_rotation_y", "attach_offset_rotation_z", "fixed_base"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of TwinSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if glb_file (nullable) is None
        # and model_fields_set contains the field
        if self.glb_file is None and "glb_file" in self.model_fields_set:
            _dict['glb_file'] = None

        # set to None if urdf_file (nullable) is None
        # and model_fields_set contains the field
        if self.urdf_file is None and "urdf_file" in self.model_fields_set:
            _dict['urdf_file'] = None

        # set to None if joint_states (nullable) is None
        # and model_fields_set contains the field
        if self.joint_states is None and "joint_states" in self.model_fields_set:
            _dict['joint_states'] = None

        # set to None if kinematics_override (nullable) is None
        # and model_fields_set contains the field
        if self.kinematics_override is None and "kinematics_override" in self.model_fields_set:
            _dict['kinematics_override'] = None

        # set to None if joint_calibration (nullable) is None
        # and model_fields_set contains the field
        if self.joint_calibration is None and "joint_calibration" in self.model_fields_set:
            _dict['joint_calibration'] = None

        # set to None if controller_policy_uuid (nullable) is None
        # and model_fields_set contains the field
        if self.controller_policy_uuid is None and "controller_policy_uuid" in self.model_fields_set:
            _dict['controller_policy_uuid'] = None

        # set to None if visibility (nullable) is None
        # and model_fields_set contains the field
        if self.visibility is None and "visibility" in self.model_fields_set:
            _dict['visibility'] = None

        # set to None if attach_to_twin_uuid (nullable) is None
        # and model_fields_set contains the field
        if self.attach_to_twin_uuid is None and "attach_to_twin_uuid" in self.model_fields_set:
            _dict['attach_to_twin_uuid'] = None

        # set to None if attach_to_link (nullable) is None
        # and model_fields_set contains the field
        if self.attach_to_link is None and "attach_to_link" in self.model_fields_set:
            _dict['attach_to_link'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of TwinSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "uuid": obj.get("uuid"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "asset_uuid": obj.get("asset_uuid"),
            "environment_uuid": obj.get("environment_uuid"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "glb_file": obj.get("glb_file"),
            "urdf_file": obj.get("urdf_file"),
            "position_x": obj.get("position_x"),
            "position_y": obj.get("position_y"),
            "position_z": obj.get("position_z"),
            "rotation_w": obj.get("rotation_w"),
            "rotation_x": obj.get("rotation_x"),
            "rotation_y": obj.get("rotation_y"),
            "rotation_z": obj.get("rotation_z"),
            "scale_x": obj.get("scale_x"),
            "scale_y": obj.get("scale_y"),
            "scale_z": obj.get("scale_z"),
            "joint_states": obj.get("joint_states"),
            "kinematics_override": obj.get("kinematics_override"),
            "joint_calibration": obj.get("joint_calibration"),
            "metadata": obj.get("metadata"),
            "capabilities": obj.get("capabilities"),
            "controller_policy_uuid": obj.get("controller_policy_uuid"),
            "visibility": obj.get("visibility"),
            "attach_to_twin_uuid": obj.get("attach_to_twin_uuid"),
            "attach_to_link": obj.get("attach_to_link"),
            "attach_offset_x": obj.get("attach_offset_x"),
            "attach_offset_y": obj.get("attach_offset_y"),
            "attach_offset_z": obj.get("attach_offset_z"),
            "attach_offset_rotation_w": obj.get("attach_offset_rotation_w"),
            "attach_offset_rotation_x": obj.get("attach_offset_rotation_x"),
            "attach_offset_rotation_y": obj.get("attach_offset_rotation_y"),
            "attach_offset_rotation_z": obj.get("attach_offset_rotation_z"),
            "fixed_base": obj.get("fixed_base")
        })
        return _obj


