# coding: utf-8

"""
    Cyberwave API

    Cyberwave platform REST API. Use 'Bearer YOUR_TOKEN' for authentication.

    The version of the OpenAPI document: 1.0.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from pydantic import BaseModel, ConfigDict, StrictBool, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from cyberwave.rest.models.workflow_connection_schema import WorkflowConnectionSchema
from cyberwave.rest.models.workflow_node_schema import WorkflowNodeSchema
from typing import Optional, Set
from typing_extensions import Self

class WorkflowSchema(BaseModel):
    """
    Workflow schema.
    """ # noqa: E501
    uuid: StrictStr
    name: StrictStr
    description: StrictStr
    is_active: StrictBool
    workspace_uuid: StrictStr
    visibility: StrictStr
    created_at: datetime
    updated_at: datetime
    created_by: Optional[StrictStr] = None
    updated_by: Optional[StrictStr] = None
    metadata: Dict[str, Any]
    nodes: Optional[List[WorkflowNodeSchema]] = None
    connections: Optional[List[WorkflowConnectionSchema]] = None
    __properties: ClassVar[List[str]] = ["uuid", "name", "description", "is_active", "workspace_uuid", "visibility", "created_at", "updated_at", "created_by", "updated_by", "metadata", "nodes", "connections"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of WorkflowSchema from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in nodes (list)
        _items = []
        if self.nodes:
            for _item_nodes in self.nodes:
                if _item_nodes:
                    _items.append(_item_nodes.to_dict())
            _dict['nodes'] = _items
        # override the default output from pydantic by calling `to_dict()` of each item in connections (list)
        _items = []
        if self.connections:
            for _item_connections in self.connections:
                if _item_connections:
                    _items.append(_item_connections.to_dict())
            _dict['connections'] = _items
        # set to None if created_by (nullable) is None
        # and model_fields_set contains the field
        if self.created_by is None and "created_by" in self.model_fields_set:
            _dict['created_by'] = None

        # set to None if updated_by (nullable) is None
        # and model_fields_set contains the field
        if self.updated_by is None and "updated_by" in self.model_fields_set:
            _dict['updated_by'] = None

        # set to None if nodes (nullable) is None
        # and model_fields_set contains the field
        if self.nodes is None and "nodes" in self.model_fields_set:
            _dict['nodes'] = None

        # set to None if connections (nullable) is None
        # and model_fields_set contains the field
        if self.connections is None and "connections" in self.model_fields_set:
            _dict['connections'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of WorkflowSchema from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "uuid": obj.get("uuid"),
            "name": obj.get("name"),
            "description": obj.get("description"),
            "is_active": obj.get("is_active"),
            "workspace_uuid": obj.get("workspace_uuid"),
            "visibility": obj.get("visibility"),
            "created_at": obj.get("created_at"),
            "updated_at": obj.get("updated_at"),
            "created_by": obj.get("created_by"),
            "updated_by": obj.get("updated_by"),
            "metadata": obj.get("metadata"),
            "nodes": [WorkflowNodeSchema.from_dict(_item) for _item in obj["nodes"]] if obj.get("nodes") is not None else None,
            "connections": [WorkflowConnectionSchema.from_dict(_item) for _item in obj["connections"]] if obj.get("connections") is not None else None
        })
        return _obj


